Module builtin

Module builtin 

Structs

IdleProcess
A tombstone process that simply waits for a shutdown request.
RestartBackoff
Exponential backoff settings for RestartSupervisor.
RestartSupervisor
Wraps one child Runnable and restarts it after failures with backoff.
SignalReceiver
Built-in Runnable that converts POSIX signals into shutdown / reload requests and propagates them through the process-manager runtime.